<?php
/**
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) exit;

global $product, $woocommerce;

/*Ensure visibility*/
if ( empty( $product ) || ! $product->is_visible() ) return;

/*product id*/
$pid = $product->get_id();

/*price*/
$p_price = $product->get_price_html();

/*description*/
$p_desc = get_the_excerpt($pid);

/*image*/
$img_id  = get_post_thumbnail_id($pid);
$img_src = wp_get_attachment_image_src($img_id, 'shop_catalog');
$origin_src = $img_src;
$img_alt = minera_img_alt($img_id, esc_html__( 'Product image', 'minera' ));
/*add to Cart url*/
$atc_url = $product->add_to_cart_url();

/*product type*/
$variation = $product->is_type( 'variable' );
$external = $product->is_type( 'external' );

if( $variation ){
    /*show swatch image default if it select*/
    $vars = $product->get_available_variations();
    $default_attr = method_exists( $product, 'get_default_attributes' ) ? $product->get_default_attributes() : array();

    /**/
    $attributes = $product->get_attributes();

    foreach($attributes as $key){
        $attr_type = $key['name'];/*swatches type*/
        foreach($vars as $key){
            $slug = isset($key['attributes']['attribute_' . $attr_type]) ? $key['attributes']['attribute_' . $attr_type] : '';
            if(isset($default_attr[$attr_type]) && $default_attr[$attr_type] === $slug){
                $img_src = wp_get_attachment_image_src($key['image_id'], 'shop_catalog');
                break;
            }
        }
    }
}

?>



<li <?php post_class( 'p-col' ); ?>>
    <div class="p-head-cont">
        <div class="p-head">
            <?php do_action( 'woocommerce_before_shop_loop_item_title' ); ?>
        </div>
        <div class="p-content">
            <a class="p-title" href="<?php echo get_permalink($pid); ?>" aria-label="<?php esc_attr_e('Product title', 'minera'); ?>"><?php echo get_the_title($pid); ?></a>
            <div class="price" aria-label="<?php esc_attr_e('Product price', 'minera'); ?>"><?php echo wp_kses_post($p_price); ?></div>
            <div class="p-attr">
                <?php minera_swatches_list();/*swatches color*/ ?>
            </div>
            <div class="p-desc" aria-label="<?php esc_attr_e('Product description', 'minera'); ?>"><?php echo wp_kses_post($p_desc); ?></div>
            <?php /*list style: add to Cart button*/ ?>
            <div class="atc-shop-list">
                <?php if( $variation ): ?>
                    <a href="<?php echo get_permalink($pid); ?>" class="atc-select-option-btn" aria-label="<?php esc_attr_e('Select Options', 'minera'); ?>"><?php esc_html_e('Select Options', 'minera'); ?></a>
                <?php elseif( $external ): ?>
                    <a href="<?php echo esc_url( $product->get_product_url() ); ?>" class="atc-select-option-btn" aria-label="<?php esc_attr_e( 'Goto to product', 'minera' ); ?>"><?php esc_html_e( 'Goto to product', 'minera' ); ?></a>
                <?php else: ?>
                    <a href="<?php echo esc_url($atc_url); ?>" data-quantity="1" data-product_id="<?php echo esc_attr($pid); ?>" class="add_to_cart_button <?php echo minera_ajax_act_opt(); ?>" aria-label="<?php esc_attr_e('Add to Cart', 'minera'); ?>"><?php esc_html_e('Add to Cart', 'minera'); ?></a>
                <?php endif; ?>
            </div>
        </div>
        <div class="p-attr">
            <?php minera_swatches_list();/*swatches color*/ ?>
        </div>
    </div>
</li>