<?php
/**
 * Single Product Image
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.3.2
 */

if ( ! defined( 'ABSPATH' ) ) exit;

global $post, $product;

if(!has_post_thumbnail()) return;

/*gallery layout list*/
$c_shop_layout = get_theme_mod('c_shop_layout', 'horizontal');
$type = $c_shop_layout;

$p_shop_layout = function_exists('fw_get_db_post_option') ? fw_get_db_post_option($post->ID, 'p_shop_layout') : 'default';
if(isset($p_shop_layout) && $p_shop_layout != 'default'){
    $type = $p_shop_layout;
}

/*sale*/
$sale = $product->is_on_sale();
$sale_price = $product->get_sale_price();
$regular_price = $product->get_regular_price();
/*variation product*/
$variation = $product->is_type( 'variable' );
/*img id*/
$img_id = get_post_thumbnail_id( $post->ID );
/*img alt*/
$img_alt = minera_img_alt($img_id, esc_html__('Product image', 'minera'));
/*img full size*/
$image = wp_get_attachment_image_src( $img_id, 'full' );
/*img view on main carousel*/
$slide_img = wp_get_attachment_image_src( $img_id, 'shop_single' );
/*img thumbnail*/
$slide_thumb = $type != 'list' ? wp_get_attachment_image_src( $img_id, 'thumbnail' ) : wp_get_attachment_image_src( $img_id, 'full' );
/*gallery ids*/
$gallery_ids = $product->get_gallery_image_ids(); ?>

<div class="w-images-box w-layout-<?php echo ($type != 'list') ? 'slider' : 'list'; ?>">
    <?php if ( $sale ) : ?><span class="onsale"><?php if($variation){
            esc_html_e('Sale!', 'minera');
        }else{
            $final_price = (($regular_price - $sale_price) / $regular_price) * 100;
            echo '-' . round( $final_price ) . '%';
        } ?></span>
    <?php endif; ?>

    <?php /*CREATE ATTRIBUTE*/
        $tag = 'div';
        $main_id = $class = $attr = $img_attr = '';
        if( true == get_theme_mod( 'effect_off', true ) ){
            if(get_theme_mod('c_shop_lightbox', false) == true){
                /*FOR LIGHTBOX OPTION*/
                $main_id = 'product-lightbox';
                $tag = 'a';
                $attr = 'href="' . esc_url($image[0]) . '"';
                $img_attr = 'data-original-src-width="' . $image[1] . '" data-original-src-height="' . $image[2] . '"';
            }else{
                /*FOR EZ-ZOOM OPTION*/
                $attr = 'data-zoom="' . esc_url($image[0]) . '"';
                $class = 'ez-zoom';
            }
        }
    ?>

    <div class="w-img-crs w-crs" id="<?php echo esc_attr($main_id); ?>">
        <<?php echo esc_attr($tag); ?> <?php echo wp_kses_post($attr); ?> class="w-img-item <?php echo esc_attr($class); ?>">
            <img src="<?php echo esc_url($slide_img[0]); ?>" <?php echo wp_kses_post($img_attr); ?> alt="<?php echo esc_attr($img_alt); ?>">
        </<?php echo esc_attr($tag); ?>>
        <?php if($gallery_ids): /*GET MAIN IMAGE SLIDE FROM GALLERY IMAGE*/
            foreach($gallery_ids as $key):
                $image_in_gallery = wp_get_attachment_image_src( $key, 'full' );/*full image*/
                if(!empty($image_in_gallery)):
                    $slide_in_gallery = wp_get_attachment_image_src( $key, 'shop_single' );/*thumbnail image*/
                    $img_alt = minera_img_alt($key, 'Product image thumbnail');

                    if(get_theme_mod('c_shop_lightbox', false) == true){
                        /*FOR LIGHTBOX OPTION*/
                        $attr = 'href="' . esc_url($image_in_gallery[0]) . '"';
                        $img_attr = 'data-original-src-width="' . $image_in_gallery[1] . '" data-original-src-height="' . $image_in_gallery[2] . '"';
                    }else{
                        /*FOR EZ-ZOOM OPTION*/
                        $attr = 'data-zoom="' . esc_url($image_in_gallery[0]) . '"';
                    } ?>

                    <<?php echo esc_attr($tag); ?> <?php echo wp_kses_post($attr); ?> class="w-img-item <?php echo esc_attr($class); ?>">
                        <img src="<?php echo esc_url($slide_in_gallery[0]); ?>" <?php echo wp_kses_post($img_attr); ?> alt="<?php echo esc_attr($img_alt); ?>">
                    </<?php echo esc_attr($tag); ?>>
            <?php endif; ?>
        <?php endforeach; endif; ?>
    </div>
    <?php if($gallery_ids && $type != 'list'):/*gallery empty*/ ?>
        <div class="w-thumb-crs w-crs">
            <div class="w-thumb-item">
                <img src="<?php echo esc_url($slide_thumb[0]); ?>" alt="<?php echo esc_attr($img_alt); ?>">
            </div>
            <?php foreach($gallery_ids as $key):
                $thumb = $type != 'list' ? wp_get_attachment_image_src( $key, 'thumbnail' ) : wp_get_attachment_image_src( $key, 'full' );
                if($thumb):
                    $img_alt = minera_img_alt($key, 'Product image thumbnail'); ?>
                    <div class="w-thumb-item">
                        <img src="<?php echo esc_url($thumb[0]); ?>" alt="<?php echo esc_attr($img_alt); ?>">
                    </div>
                <?php endif; ?>
            <?php endforeach; ?>
        </div>
    <?php endif; ?>
</div>

<?php /*product sticky*/

if($type == 'list'){
    $offet = get_theme_mod('sticky', false) == true ? 100 : 40;

    wp_enqueue_script('minera-product-sticky-content', get_template_directory_uri() . '/js/sticky.min.js', false, true);
    wp_add_inline_script(
        'minera-product-sticky-content',
        "$('.w-summary-box').stick_in_parent({
            parent: '.w-data-view',
            offset_top: {$offet}
        });",
        'after'
    );
}

if(get_theme_mod('c_shop_lightbox', false) == true){
    wp_add_inline_script(
        'minera-pswp-lightbox-script',
        "$('#{$main_id}').photoSwipe(
        '.w-img-item',
        {
            bgOpacity: 0.9,
            shareEl: false
        });",
        'after'
    );
}